package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ScoreUserMapper;
import com.ruoyi.system.domain.ScoreUser;
import com.ruoyi.system.service.IScoreUserService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-10-30
 */
@Service
public class ScoreUserServiceImpl implements IScoreUserService
{
    @Autowired
    private ScoreUserMapper scoreUserMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param userId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public ScoreUser selectScoreUserByUserId(Long userId)
    {
        return scoreUserMapper.selectScoreUserByUserId(userId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param scoreUser 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<ScoreUser> selectScoreUserList(ScoreUser scoreUser)
    {
        return scoreUserMapper.selectScoreUserList(scoreUser);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param scoreUser 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertScoreUser(ScoreUser scoreUser)
    {
        // 判断当前openId是否已经有值了
        ScoreUser scoreUser1 = scoreUserMapper.selectScoreUserByOpenId(scoreUser.getOpenId());
        if(scoreUser1 != null) {
            return 1;
        }

        scoreUser.setCreateTime(DateUtils.getNowDate());
        return scoreUserMapper.insertScoreUser(scoreUser);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param scoreUser 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateScoreUser(ScoreUser scoreUser)
    {
        scoreUser.setUpdateTime(DateUtils.getNowDate());
        return scoreUserMapper.updateScoreUser(scoreUser);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param userIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteScoreUserByUserIds(Long[] userIds)
    {
        return scoreUserMapper.deleteScoreUserByUserIds(userIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param userId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteScoreUserByUserId(Long userId)
    {
        return scoreUserMapper.deleteScoreUserByUserId(userId);
    }

    @Override
    public ScoreUser login(ScoreUser scoreUser) {
        // 判断是否有 userId
        if (scoreUser.getUserId() != null) {
            return scoreUserMapper.selectScoreUserByUserId(scoreUser.getUserId());
        }
        // 如果没有userId, 使用openId查询
        if(scoreUser.getOpenId() != null) {
            return scoreUserMapper.selectScoreUserByOpenId(scoreUser.getOpenId());
        }
        return null;
    }
}
